@@ -1,4 +1,4 @@
-/* $Id: keyboard-drawing.c,v 1.45 2005/10/07 23:03:57 svu Exp $ */
+/* $Id: keyboard-drawing.c,v 1.46 2006/01/30 10:48:20 davyd Exp $ */
 /*
  * keyboard-drawing.c: implementation of a gtk+ widget that is a drawing of
  * the keyboard of the default display
@@ -1321,7 +1321,7 @@ init_keys_and_doodads (
         }
     }
 
-  g_list_sort (drawing->keyboard_items,
+  drawing->keyboard_items = g_list_sort (drawing->keyboard_items,
                (GCompareFunc) compare_keyboard_item_priorities);
 }
 
