@@ -27,8 +27,8 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "metacity-window-manager.h"
 
@@ -103,7 +103,7 @@ add_themes_from_dir (GList *current_list, const char *path)
          * only checks existence, not wether we can really read it.*/
         if (theme_dir == NULL)
                 return current_list;
-
+        
         for (entry = readdir (theme_dir); entry != NULL; entry = readdir (theme_dir)) {
                 theme_file_path = g_build_filename (path, entry->d_name, "metacity-1/metacity-theme-1.xml", NULL);
 
